/******************************************************************************
* Filename     : cs8900a.h                                                    *
* Program      : loader.                                                      *
* Copyright    : E2G                                                          *
* Author       : Sunyean Jang                                                 *
* Description  : Header file for cs8900a.c                                    *
* Created at   : 2003-12-24                                                   *
* Based on     :                CS8900A device driver.                        *
* Modified by  :                                                              *
* Modified at  :                                                              *
******************************************************************************/
/*   ҽ E2G  uCOS ̴ ̹  Դϴ.
 * StrongARM̳ ARM Ÿٺ忡 ̽ ϸ, Ÿ 32bit μ
 * ̽ մϴ.   ο,  ҽ ؼ ߻ϴ  
 * åӵ  E2G  ʽϴ.
 */

#include "lstring.h"

#define MAX_PKT_SIZE            1024 // Ŷΰ   Ʋ
#define DEBUG                   true
//*****************************************************************************
// CONSTANTS
//*****************************************************************************

// I/O Mode Mapping Register
//#define	IO_BASE			0x08000300 //HYPER
#define	IO_BASE			0x10000300       //EZBoard
#define IO_RTX_DATA		*((volatile short *)(IO_BASE + 0x00000000))	// RTx data.
#define IO_TXCMD		*((volatile short *)(IO_BASE + 0x00000004))	// RTx command.
#define IO_TXLEN		*((volatile short *)(IO_BASE + 0x00000006))	// transmit length.
#define IO_ISQ			*((volatile short *)(IO_BASE + 0x00000008))	// interrupt.
#define IO_PPPTR		*((volatile short *)(IO_BASE + 0x0000000a))	// packet page point.
#define IO_PPDATA		*((volatile short *)(IO_BASE + 0x0000000c))	// packet page data.

// ID.
#define PP_ChipID		0x0000	// First  Chip ID. CS8900A : 0x630E
#define PP_ChipID2		0x0002	// Second Chip ID. CS8900A : 0x0800

#define PP_ISAIOB		0x0020	//  IO base address
#define PP_CS8900_ISAINT	0x0022	//  ISA interrupt select
#define PP_CS8920_ISAINT	0x0370	//  ISA interrupt select
#define PP_CS8900_ISADMA	0x0024	//  ISA Rec DMA channel
#define PP_CS8920_ISADMA	0x0374	//  ISA Rec DMA channel
#define PP_ISASOF		0x0026	//  ISA DMA offset
#define PP_DmaFrameCnt		0x0028	//  ISA DMA Frame count
#define PP_DmaByteCnt		0x002A	//  ISA DMA Byte count
#define PP_CS8900_ISAMemB	0x002C	//  Memory base
#define PP_CS8920_ISAMemB	0x0348	// 

#define PP_ISABootBase		0x0030	//  Boot Prom base 
#define PP_ISABootMask		0x0034	//  Boot Prom Mask

//Control Register : PP_  Register ǹ̷ 
#define PP_LineCtlReg           0x0112  // Line control Register
#define PP_TestCtlReg           0x0118  // Test Control Register
#define PP_RcvCfgReg            0x0102  // Receiver Configuration
#define PP_RcvCtlReg            0x0104  // Receiver Control 
#define PP_TranCfgReg           0x0106  // Transmit Configuration
#define PP_TranCmdSts           0x0108  // Transmitter Command Status
#define PP_BufCfg               0x010a  // Buffer Configuration
#define PP_BusCtl               0x0116  // Bus Controller
#define PP_TxCMD                0x0114  // Transmitter Command
#define PP_BusST                0x0138  // 
#define PP_RxEvent              0x0124  // Receive Event
#define PP_TxEvent              0x0218  // Transmmiter Event
#define PP_BufEvent             0x012c  // Buffer Event
#define PP_SelfCtl              0x0114  // Self Control
#define PP_SelfST               0x0136  // Self Status

#define PP_LAF			0x0150	//  Hash Table
#define PP_IA			0x0158	//  Physical Address Register

//Transmision Commands
#define TX_AFTER_ALL            0x0c00  // ü  

//Event 
#define RxOK                    0x0100  // Receiver Event :  
#define RxEvent                 0x0004  // ISQ  
#define All_Int_High_Impedence  0x0004  //  ͷƮ  High Impedence 
#define All_DMA_High_Impedence  0x0003  //  DMA  High Impedence 

// PP_RxCFG - Receive  Configuration and Interrupt Mask bit definition
#define SKIP_1			0x0040
#define RX_STREAM_ENBL		0x0080
#define RX_OK_ENBL		0x0100
#define RX_DMA_ONLY		0x0200
#define AUTO_RX_DMA		0x0400
#define BUFFER_CRC		0x0800
#define RX_CRC_ERROR_ENBL	0x1000
#define RX_RUNT_ENBL		0x2000
#define RX_EXTRA_DATA_ENBL	0x4000

// PP_RxCTL - Receive Control bit definition - Read/write.
#define RX_IA_HASH_ACCEPT			0x0040
#define RX_PROM_ACCEPT				0x0080
#define RX_OK_ACCEPT				0x0100
#define RX_MULTICAST_ACCEPT			0x0200
#define RX_IA_ACCEPT				0x0400
#define RX_BROADCAST_ACCEPT			0x0800
#define RX_BAD_CRC_ACCEPT			0x1000
#define RX_RUNT_ACCEPT				0x2000
#define RX_EXTRA_DATA_ACCEPT		0x4000
#define RX_ALL_ACCEPT (RX_PROM_ACCEPT|RX_BAD_CRC_ACCEPT|RX_RUNT_ACCEPT|RX_EXTRA_DATA_ACCEPT)
//  Default receive mode - individually addressed, broadcast, and error free.
#define DEF_RX_ACCEPT (RX_IA_ACCEPT | RX_BROADCAST_ACCEPT | RX_OK_ACCEPT)

// PP_TxCFG - Transmit Configuration Interrupt Mask bit definition - Read/write.
#define TX_LOST_CRS_ENBL			0x0040
#define TX_SQE_ERROR_ENBL			0x0080
#define TX_OK_ENBL				0x0100
#define TX_LATE_COL_ENBL			0x0200
#define TX_JBR_ENBL				0x0400
#define TX_ANY_COL_ENBL				0x0800
#define TX_16_COL_ENBL				0x8000

// PP_TxCMD - Transmit Command bit definition - Read-only.
#define TX_START_4_BYTES			0x0000
#define TX_START_64_BYTES			0x0040
#define TX_START_128_BYTES			0x0080
#define TX_START_ALL_BYTES			0x00C0
#define TX_FORCE				0x0100
#define TX_ONE_COL				0x0200
#define TX_TWO_PART_DEFF_DISABLE		0x0400
#define TX_NO_CRC				0x1000
#define TX_RUNT					0x2000

// PP_BufCFG - Buffer Configuration Interrupt Mask bit definition - Read/write.
#define GENERATE_SW_INTERRUPT			0x0040
#define RX_DMA_ENBL				0x0080
#define READY_FOR_TX_ENBL			0x0100
#define TX_UNDERRUN_ENBL			0x0200
#define RX_MISS_ENBL				0x0400
#define RX_128_BYTE_ENBL			0x0800
#define TX_COL_COUNT_OVRFLOW_ENBL		0x1000
#define RX_MISS_COUNT_OVRFLOW_ENBL		0x2000
#define RX_DEST_MATCH_ENBL			0x8000

// PP_LineCTL - Line Control bit definition - Read/write.
#define SERIAL_RX_ON				0x0040
#define SERIAL_TX_ON				0x0080
#define AUI_ONLY				0x0100
#define AUTO_AUI_10BASET			0x0200
#define MODIFIED_BACKOFF			0x0800
#define NO_AUTO_POLARITY			0x1000
#define TWO_PART_DEFDIS				0x2000
#define LOW_RX_SQUELCH				0x4000

// PP_BusCTL - ISA Bus Control bit definition - Read/write.
#define RESET_RX_DMA				0x0040
#define MEMORY_ON				0x0400
#define DMA_BURST_MODE				0x0800
#define IO_CHANNEL_READY_ON			0x1000
#define RX_DMA_SIZE_64K				0x2000
#define ENABLE_IRQ				0x8000

//Self Control
#define RESET                                   0x0055
//Self Status
#define INITD                                   0x0096
#define VoltAct                                 0x0046

//Status Register
#define PP_RxStatus                		0x0400  // RxStatus 
#define PP_RxLength                		0x0402  // 

//EEPROM
#define EEPROM_CMD              *((volatile short *)(IO_BASE + 0x0040))
#define EEPROM_DATA             *((volatile short *)(IO_BASE + 0x0042))
//*****************************************************************************
// FUNCTIONS
//*****************************************************************************
bool     EthInit(void);                                // Ethernet Initialize
bool     TransmitFrame(short TxLength, void * Data);
bool     ReceiveFrame(void * data);